@@ -6,4 +6,4 @@ import numpy as np
 import matplotlib.pyplot as plt
 from scipy.integrate import odeint
 from .NHL import *
-from .Simulation.Simulation import *
+from .Simulation import *
